# Copyright (C) 2008-2009 - INRIA - Michael Baudin
# Copyright (C) 2009-2010 - DIGITEO - Michael Baudin
# Copyright (C) 2010 - Sebastien Bihorel
#
# This file must be used under the terms of the CeCILL.
# This source file is licensed as described in the file COPYING, which
# you should have received as part of this distribution. The terms
# are also available at
# http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt
#
# This source code is a R port of the optimsimplex component
# originally written by Michael Baudin for Scilab.

optimsimplex.setallx <- function(this=NULL,x=NULL){

  nx1 <- size(x,1)
  if (nx1!=this$nbve)
    stop(sprintf('optimsimplex.setallx: The number of rows in x is %d, while expected %d.',
                 nx1,this$nbve),
         call.=FALSE)
  nx2 <- size(x,2)
  if (nx2!=this$n)
    stop(sprintf('optimsimplex.setallx: The number of columns in x is %d, while expected %d.',
                 nx2,this$n),
         call.=FALSE)
  this$x[1:this$nbve,1:this$n] <- x[1:this$nbve,1:this$n,drop=FALSE]

  return(this)

}

